@@ -116,7 +116,7 @@ class BitmexOrder:
 
     def check_open_bot_order(self, symbol, entry, sl):
         settings = pickle.load(open(self._settings_path, 'rb'))
-        self.props[symbol]['stoploss_id'] = settings.symbols[symbol].last_order_id
+        self.props[symbol]['stoploss_id'] = settings.symbols[symbol]['last_order_id']
         if self.props[symbol]['stoploss_id']:
             try:
                 res = self.client.client.Order.Order_getOrders(
@@ -132,7 +132,7 @@ class BitmexOrder:
     def save_open_id(self, symbol, id):
         self.props[symbol]['stoploss_id'] = id
         settings = pickle.load(open(self._settings_path, 'rb'))
-        settings.symbols[symbol].last_order_id = id
+        settings.symbols[symbol]['last_order_id'] = id
         pickle.dump(settings, file=open(self._settings_path, 'wb'))
 
     def manage_entries(self, symbols):
