@@ -16,14 +16,7 @@ class BrokerSettings:
     token = ''
     api_key = ''
     api_secret = ''
-    symbols = []
-
-
-class Symbol():
-    def __init__(self, name, position_size=1, last_order_id=''):
-        self.name = name
-        self.position_size = position_size
-        self.last_order_id = last_order_id
+    symbols = {}
 
 
 def bot_settings(symbols=['XBTUSD'], strategy='lotus', broker='bitmex'):
@@ -54,13 +47,12 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
             "Submit your Strategytoken (found in your member area): ")
         api_key = input("Submit your " + broker + " API Key (ID): ")
         api_secret = input("Submit your " + broker + " API Secret: ")
-        symbol_settings = []
+        symbol_settings = {}
         for symbol in symbols:
             pos_size = input(
                 "Choose your Position Size for {} per trade in %: ".format(symbol))
             pos_size = check_pos_size(pos_size)
-            new_symbol = Symbol(name=symbol, position_size=pos_size)
-            symbol_settings.append(new_symbol)
+            symbol_settings[symbol] = {'position_size': pos_size, 'last_order_id': ''}
         return make_pickle_file(setting_name, token, api_key, api_secret, symbol_settings)
 
 
@@ -69,8 +61,7 @@ def make_pickle_file(filename, token, api_key, api_secret, symbol_settings):
     settings.token = token
     settings.api_key = api_key
     settings.api_secret = api_secret
-    for setting in symbol_settings:
-        settings.symbols.append(setting)
+    settings.symbols = symbol_settings
     pickle.dump(settings, file=open(
         os.path.join(settings_path, filename), 'wb'))
     return settings
@@ -118,9 +109,9 @@ def check_settings(settings, symbols, broker, strategy):
 
 def position_symbol_sizes(symbols):
     output = ''
-    for symbol in symbols:
-        output += '\n\t{} Position Size: {} %\n\n'.format(
-            symbol.name, symbol.position_size)
+    for key in symbols:
+        output += '\n\t{} Position Size: {} %'.format(
+            key, symbols[key]['position_size'])
     return output
 
 
