@@ -26,6 +26,11 @@ class Lotus:
         self._last_entry = {}
         self._last_sl = {}
 
+        for symbol in symbols:
+            self._last_timestamp[symbol] = datetime.datetime.utcnow()
+            self._last_entry[symbol] = ''
+            self._last_sl[symbol] = ''
+
         if not self.client.is_connected:
             print(
                 "Invalid API ID or API Secret, please restart and provide the right keys", flush=True)
@@ -33,16 +38,11 @@ class Lotus:
 
     def is_new_signal(self, signal, symbol):
         timestamp = parser.parse(signal[symbol]['timestamp'])
-        if self._last_timestamp[symbol]['timestamp'] != timestamp:
-            self._last_timestamp = timestamp
-            try:
-                if self._last_entry[symbol]['entry'] != signal[symbol]['entry'] or self._last_sl[symbol]['stoploss'] != signal[symbol]['stoploss']:
-                    self._last_entry[symbol]['entry'] = signal[symbol]['entry']
-                    self._last_sl[symbol]['stoploss'] = signal[symbol]['stoploss']
-                    return True
-            except KeyError:
-                self._last_entry[symbol]['entry'] = signal[symbol]['entry']
-                self._last_sl[symbol]['stoploss'] = signal[symbol]['stoploss']
+        if self._last_timestamp[symbol] != timestamp:
+            self._last_timestamp[symbol] = timestamp
+            if self._last_entry[symbol] != signal[symbol]['entry'] or self._last_sl[symbol] != signal[symbol]['stoploss']:
+                self._last_entry[symbol] = signal[symbol]['entry']
+                self._last_sl[symbol] = signal[symbol]['stoploss']
                 return True
 
     def get_api_signal(self):
@@ -50,8 +50,9 @@ class Lotus:
         try:
             return requests.get(self._api_endpoint, params=auth).json()
         except ValueError:
-            print("Can't get signal on endpoint {} with token {}. Please make sure your token and endpoint is set correct.".format(
-                self._api_endpoint, self.settings.token))
+            print("Can't get signal on endpoint {} with token {}. Please make sure your token is the right one and endpoint is set correct."
+                  "It could also be that you are timed out because you try to access with multiple IP's. In this case wait 40 minutes and try again.".format(
+                      self._api_endpoint, self.settings.token))
             return False
 
     def rand_sec(self, start=1, end=10):
@@ -79,7 +80,7 @@ class Lotus:
                     signal = ns[symbol]['signal']
                     if signal in [-1, 1]:  # signal has open position
                         if signal == 1:
-                            if self.order.props[symbol].qty > 0 or self.client.open_contracts(symbol) > 0:
+                            if self.order.props[symbol]['qty'] > 0 or self.client.open_contracts(symbol) > 0:
                                 self.check_modify(symbol, stoploss)
                             elif self.client.open_contracts(symbol) < 0:
                                 print('Closing {} order.'.format(
@@ -105,7 +106,7 @@ class Lotus:
                                         self.order.bracket_market_order(
                                             symbol, contracts, stoploss)
                         else:
-                            if self.order.props[symbol].qty < 0 or self.client.open_contracts(symbol) < 0:
+                            if self.order.props[symbol]['qty'] < 0 or self.client.open_contracts(symbol) < 0:
                                 self.check_modify(symbol, stoploss)
                             elif self.client.open_contracts(symbol) > 0:
                                 print('Closing order on {}.'.format(
@@ -130,13 +131,13 @@ class Lotus:
                                         self.order.bracket_market_order(
                                             symbol, -contracts, stoploss)
                     elif signal in [-2, 2]:  # signal has pending order
-                        if self.order.props[symbol].wait_stop:
+                        if self.order.props[symbol]['wait_stop']:
                             print("Cancel old order {} first.".format(symbol))
                             self.order.stoporder_cancel()  # cancel old order first
                             time.sleep(3)
                         contracts = self.order.calc_pos_size(
                             abs(entry - stoploss))
-                        if self.order.props[symbol].open:
+                        if self.order.props[symbol]['open']:
                             print("New signal is bracket stop long, but one bot order is open... closing open order in {}.".format(
                                 symbol), flush=True)
                             self.order.close(symbol)
@@ -162,13 +163,13 @@ class Lotus:
                             self.order.bracket_stop_order(
                                 symbol, -contracts, entry, stoploss)
                     else:
-                        if self.order.props[symbol].open:
+                        if self.order.props[symbol]['open']:
                             self.order.close(symbol)
 
     def run(self):
         # Main loop
         self.order = BitmexOrder(self.symbols,
-            self.client, self.settings, self._settings_path)
+                                 self.client, self.settings, self._settings_path)
         self.process_signals(start=True)
         while True:
             time.sleep(10)
